# WARNING!
# THIS IS AN AUTOGENERATED FILE!
# MANUAL CHANGES CAN AND WILL BE OVERWRITTEN!

import re
from pathlib import Path

from setuptools import setup

PACKAGE_NAME = 'personal_data'

PACKAGE_DESCRIPTION = """
# Personal Data Fetcher Systems.

This program collects several small data fetchers, for downloading personal
data spread around the internet. The fetchers are mostly related either to
personal finance, or to various nerdy hobbies.

Supported fetchers:

- [Crunchyroll](https://www.crunchyroll.com/) episode watch history
- [FFXIV Lodestone](https://eu.finalfantasyxiv.com/lodestone/) achivement history
- Playstation achievements by way of [PSN Profiles](https://psnprofiles.com/).
- [MyAnimeList](https://myanimelist.net/) watch list.
- [Stepmania](https://www.stepmania.com/)/[ITGMania](https://github.com/itgmania/itgmania)
- [WaniKani](https://wanikani.com) lesson information.
- [Jellyfin](https://jellyfin.org/) watch history.
- Account balances for several backends supported by [`fin-depo`](https://gitfub.space/Jmaa/fin-depo)
  * Partisia Blockchain BYOC and MPC trackers
  * Kraken Account Balances
  * Kucoin Account Balances

## Usage

Add relevant secrets to
a [`secret_loader`](https://gitfub.space/Jmaa/secret_loader)-compatible
location, and run:

```sh
python -m personal_data
```

Use `--help` option to see all options.

## Further expansion

- [ ] YouTube (Music): Liked videos with title and URL.
- [ ] Steam Wishlist and Achievements
- [ ] Ledger (Live?) Account Balances
- [ ] [Gandalf](https://gandalf.network/)? Seems to support a bunch of
  different sites, but not in the detail I want.
""".strip()

PACKAGE_DESCRIPTION_SHORT = """
This program collects several small data fetchers, for downloading personal
data spread around the internet.""".strip()


def parse_version_file(text: str) -> str:
    text = re.sub('^#.*', '', text, flags=re.MULTILINE)
    match = re.match(r'^\s*__version__\s*=\s*(["\'])([\d\.]+)\1$', text)
    if match is None:
        msg = 'Malformed _version.py file!'
        raise Exception(msg)
    return match.group(2)


def find_python_packages() -> list[str]:
    """
    Find all python packages. (Directories containing __init__.py files.)
    """
    root_path = Path(PACKAGE_NAME)
    packages: set[str] = set([PACKAGE_NAME])

    # Search recursively
    for init_file in root_path.rglob('__init__.py'):
        packages.add(str(init_file.parent).replace('/', '.'))

    return sorted(packages)

with open(PACKAGE_NAME + '/_version.py') as f:
    version = parse_version_file(f.read())


REQUIREMENTS_MAIN = [
    'beautifulsoup4',
    'lxml',
    'requests',
    'requests_cache',
    'browser_cookie3',
    'cfscrape @ git+https://github.com/landryraccoon/cloudflare-scrape.git',
    'frozendict',
    'python-kucoin',
    'krakenex',
    'python-frontmatter',
    'marko',
    'fin-depo @ git+https://gitfub.space/Jmaa/fin-depo.git',
    'secret_loader @ git+https://gitfub.space/Jmaa/secret_loader',
    'requests-util @ git+https://gitfub.space/Jmaa/requests_util',
    'clients @ git+https://gitfub.space/Jmaa/clients',
]
REQUIREMENTS_TEST = [
    'pytest',
]


setup(
    name=PACKAGE_NAME,
    version=version,
    description=PACKAGE_DESCRIPTION_SHORT,
    long_description=PACKAGE_DESCRIPTION,
    long_description_content_type='text/markdown',
    author='Jon Michael Aanes',
    author_email='jonjmaa@gmail.com',
    url='https://gitfub.space/Jmaa/' + PACKAGE_NAME,
    packages=find_python_packages(),
    install_requires=REQUIREMENTS_MAIN,
    extras_require={
        'test': REQUIREMENTS_TEST,
    },
    python_requires='>=3.9',
)
